@@ -13,8 +13,11 @@
 ##############################################################################
 """MIME Content-Type parsing helper functions.
 
-This supports parsing RFC 1341 Content-Type values, including
-quoted-string values as defined in RFC 822.
+This supports parsing `RFC 1341`_ Content-Type values, including
+quoted-string values as defined in `RFC 822`_.
+
+.. _RFC 1341: https://tools.ietf.org/html/rfc1341
+.. _RFC 822: https://tools.ietf.org/html/rfc822
 
 """
 __docformat__ = "reStructuredText"
@@ -27,13 +30,34 @@ import re
 
 
 def parse(string):
+    """
+    Parse the given string as a MIME type.
+
+    This uses :func:`parseOrdered` and can raise the same
+    exceptions it does.
+
+    :return: A tuple ``(major, minor, params)`` where ``major``
+      and ``minor`` are the two parts of the type, and ``params``
+      is a dictionary containing any parameters by name.
+    :param str string: The string to parse.
+    """
     major, minor, params = parseOrdered(string)
     d = {}
     for (name, value) in params:
         d[name] = value
     return major, minor, d
 
+
 def parseOrdered(string):
+    """
+    Parse the given string as a MIME type.
+
+    :return: A tuple ``(major, minor, params)``  where ``major``
+      and ``minor`` are the two parts of the type, and ``params`` is a
+      sequence of the parameters in order.
+    :raises ValueError: If the *string* is malformed.
+    :param str string: The string to parse.
+    """
     if ";" in string:
         type, params = string.split(";", 1)
         params = _parse_params(params)
@@ -47,11 +71,12 @@ def parseOrdered(string):
     major, minor = type.lower().split("/", 1)
     return _check_token(major.strip()), _check_token(minor.strip()), params
 
+
 def _parse_params(string):
     result = []
     string = string.strip()
     while string:
-        if not "=" in string:
+        if "=" not in string:
             raise ValueError("parameter values are not optional")
         name, rest = string.split("=", 1)
         name = _check_token(name.strip().lower())
@@ -66,7 +91,6 @@ def _parse_params(string):
                 raise ValueError("invalid quoted-string in %r" % rest)
             value = m.group()
             rest = rest[m.end():].strip()
-            #import pdb; pdb.set_trace()
             if rest[:1] not in ("", ";"):
                 raise ValueError(
                     "invalid token following quoted-string: %r" % rest)
@@ -86,22 +110,15 @@ def _parse_params(string):
     return result
 
 
-def _quoted_string_match(string):
-    # This support RFC 822 quoted-string values.
-    global _quoted_string_match
-    _quoted_string_match = re.compile(
-        '"(?:\\\\.|[^"\n\r\\\\])*"', re.DOTALL).match
-    return _quoted_string_match(string)
+_quoted_string_match = re.compile('"(?:\\\\.|[^"\n\r\\\\])*"', re.DOTALL).match
+_token_match = re.compile("[^][ \t\n\r()<>@,;:\"/?=\\\\]+$").match
+
 
 def _check_token(string):
     if _token_match(string) is None:
         raise ValueError('"%s" is not a valid token' % string)
     return string
 
-def _token_match(string):
-    global _token_match
-    _token_match = re.compile("[^][ \t\n\r()<>@,;:\"/?=\\\\]+$").match
-    return _token_match(string)
 
 def _unescape(string):
     assert string[0] == '"'
@@ -113,6 +130,15 @@ def _unescape(string):
 
 
 def join(spec):
+    """
+    Given a three-part tuple as produced by :func:`parse` or
+    :func:`parseOrdered`, return the string representation.
+
+    :returns: The string representation. For example, given ``('text', 'plain',
+      [('encoding','utf-8')])``, this will produce
+      ``'text/plain;encoding=utf-8'``.
+    :rtype: str
+    """
     (major, minor, params) = spec
     pstr = ""
     try:
@@ -124,8 +150,9 @@ def join(spec):
         # ensure a predictable order:
         params = sorted(params)
     for name, value in params:
-        pstr += ";%s=%s" % (name, _escape(value))
-    return "%s/%s%s" % (major, minor, pstr)
+        pstr += ";{}={}".format(name, _escape(value))
+    return "{}/{}{}".format(major, minor, pstr)
+
 
 def _escape(string):
     try:
