@@ -31,6 +31,9 @@ class ParseOrderedTestCase(unittest.TestCase):
     def oneParam(self, name, value):
         return [(name, value)]
 
+    def test_invalid_type(self):
+        self.assertRaises(ValueError, self._callFUT, 'no-slash-here')
+
     def test_without_params(self):
         self.assertEqual(self._callFUT("text/plain"),
                          ("text", "plain", self.empty_params))
@@ -41,6 +44,12 @@ class ParseOrderedTestCase(unittest.TestCase):
         self.assertEqual(self._callFUT("text / vnd.wap.wml"),
                          ("text", "vnd.wap.wml", self.empty_params))
 
+    def test_invalid_params(self):
+        self.assertRaises(ValueError,
+                          self._callFUT, 'text/plain; foo="abc')
+        self.assertRaises(ValueError,
+                          self._callFUT, 'text/plain; foo="abc" bar')
+
     def test_with_empty_params(self):
         self.assertEqual(self._callFUT("text/plain ; "),
                          ("text", "plain", self.empty_params))
@@ -110,6 +119,7 @@ class ParseOrderedTestCase(unittest.TestCase):
             self._callFUT(r'a/b;c="\\\""'),
             ("a", "b", self.oneParam("c", r'\"')))
 
+
 class ParseTestCase(ParseOrderedTestCase):
 
     empty_params = {}
@@ -154,18 +164,18 @@ class JoinTestCase(unittest.TestCase):
         # multiple parameters given as a list maintain order:
         self.assertEqual(
             self._callFUT(("text", "plain",
-                              [("charset", "UTF-8"), ("format", "flowed")])),
+                           [("charset", "UTF-8"), ("format", "flowed")])),
             "text/plain;charset=UTF-8;format=flowed")
         self.assertEqual(
             self._callFUT(("text", "plain",
-                              [("format", "flowed"), ("charset", "UTF-8")])),
+                           [("format", "flowed"), ("charset", "UTF-8")])),
             "text/plain;format=flowed;charset=UTF-8")
 
     def test_multi_params_dict_sorted_order(self):
         # multiple parameters given as a dict are sorted by param name:
         self.assertEqual(
             self._callFUT(("text", "plain",
-                              {"charset": "UTF-8", "format": "flowed"})),
+                           {"charset": "UTF-8", "format": "flowed"})),
             "text/plain;charset=UTF-8;format=flowed")
 
     def test_params_list_quoted(self):
@@ -196,8 +206,4 @@ class JoinTestCase(unittest.TestCase):
 
 
 def test_suite():
-    return unittest.TestSuite((
-        unittest.makeSuite(ParseOrderedTestCase),
-        unittest.makeSuite(ParseTestCase),
-        unittest.makeSuite(JoinTestCase),
-    ))
+    return unittest.defaultTestLoader.loadTestsFromName(__name__)
